pub struct QuerySource(pub &'static str);Expand description
Extracts a token from a named query parameter (e.g., ?token=xxx).
The inner &'static str is the parameter name to look up.
Tuple Fields
0: &'static strTrait Implementations
Sourceimpl TokenSource for QuerySource
impl TokenSource for QuerySource