pub struct OAuthState { /* private fields */ }Expand description
OAuth 2.0 state extracted from the signed _oauth_state cookie.
This is an axum extractor. Add it as a handler parameter on your callback route to
automatically parse and verify the state cookie that was set by AuthorizationRequest.
Requires a Key to be registered in the
Registry so that the cookie signature can be verified.
Returns crate::Error::bad_request if the cookie is missing, tampered with, or
structurally invalid.