pub struct CorsConfig {
pub origins: CorsOrigins,
pub credentials: bool,
pub max_age_secs: Option<u64>,
}Expand description
CORS policy configuration used by AppBuilder::cors.
Defaults to mirroring the request origin (permissive but not *).
Fields
origins: CorsOriginscredentials: boolmax_age_secs: Option<u64>Implementations
Sourceimpl CorsConfig
impl CorsConfig
Sourcepub fn permissive() -> Self
pub fn permissive() -> Self
Create a permissive config that mirrors the request origin (the default).
Sourcepub fn with_origins(origins: &[&str]) -> Self
pub fn with_origins(origins: &[&str]) -> Self
Create a config that allows only the specified origins.
Sourcepub fn with_custom_check(
f: impl Fn(&str) -> bool + Send + Sync + 'static,
) -> Self
pub fn with_custom_check( f: impl Fn(&str) -> bool + Send + Sync + 'static, ) -> Self
Create a config with a custom origin predicate.
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Validates the CORS configuration.
Returns an error if credentials is true with Any or Mirror
origins, which would allow any origin to send credentialed requests.
Sourcepub fn into_layer(self) -> CorsLayer
pub fn into_layer(self) -> CorsLayer
Convert into a tower-http CorsLayer for use in the middleware stack.