Module hex

Module hex 

modo::encoding::hex

Lowercase hexadecimal encoding and SHA-256 digest helper.

Provides:

  • encode — encode a byte slice to a lowercase hex string
  • sha256 — SHA-256 hash of input, returned as a 64-character hex string

Functions

encode
Encode a byte slice as a lowercase hexadecimal string.
sha256
SHA-256 hash of data, returned as a 64-character lowercase hex string.