pub struct JsonRequest<T>(pub T);Expand description
Axum extractor that deserializes a JSON request body into T and then sanitizes it.
Returns a 400 Bad Request error if the body is not valid JSON or cannot be
deserialized. T must implement both serde::de::DeserializeOwned and
crate::sanitize::Sanitize.
Example
use modo::extractor::JsonRequest;
use modo::sanitize::Sanitize;
use serde::Deserialize;
#[derive(Deserialize)]
struct CreateItem { name: String }
impl Sanitize for CreateItem {
fn sanitize(&mut self) { self.name = self.name.trim().to_string(); }
}
async fn create(JsonRequest(body): JsonRequest<CreateItem>) {
// body.name is already trimmed
}Tuple Fields
0: TTrait Implementations
Sourceimpl<S, T> FromRequest<S> for JsonRequest<T>
impl<S, T> FromRequest<S> for JsonRequest<T>