#[non_exhaustive]pub struct I18nConfig {
pub locales_path: String,
pub default_locale: String,
pub locale_cookie: String,
pub locale_query_param: String,
}Expand description
Configuration for the i18n module.
All fields have sensible defaults and can be overridden via YAML config. Paths are relative to the working directory of the running process.
Defaults
| Field | Default |
|---|---|
locales_path | "locales" |
default_locale | "en" |
locale_cookie | "lang" |
locale_query_param | "lang" |
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.locales_path: StringDirectory that contains locale subdirectories with YAML translation files.
default_locale: StringBCP 47 language tag used when no locale can be resolved from the request.
Cookie name read by CookieResolver to determine the active locale.
locale_query_param: StringQuery-string parameter name read by QueryParamResolver.