#[non_exhaustive]pub struct QueueConfig {
pub name: String,
pub concurrency: u32,
}Expand description
Configuration for a single named queue.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringQueue name. Must match the queue field used when enqueuing jobs.
concurrency: u32Maximum number of jobs from this queue that run concurrently.
Defaults to 4.