Config

Struct Config 

#[non_exhaustive]
pub struct Config { pub host: String, pub port: u16, pub shutdown_timeout_secs: u64, }
HTTP server configuration.

Deserialized from the server section of the application YAML config file. All fields have sane defaults so the section may be omitted entirely.

YAML example

server:
  host: 0.0.0.0
  port: ${PORT:8080}
  shutdown_timeout_secs: 30

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
host: String

Network interface to bind. Defaults to "localhost".

port: u16

TCP port to listen on. Defaults to 8080.

shutdown_timeout_secs: u64

Maximum seconds to wait for in-flight requests to complete during graceful shutdown. Defaults to 30.