pub struct Service<T>(pub Arc<T>);Expand description
Axum extractor that retrieves a service T from the application’s service registry.
The inner value is an Arc<T>, so cloning the extractor is cheap.
Returns a 500 Internal Server Error if T was not registered before the server started.
Example
use modo::service::Service;
struct MyService;
async fn handler(Service(svc): Service<MyService>) {
// svc is Arc<MyService>
}Tuple Fields
0: Arc<T>Trait Implementations
Sourceimpl<T: Send + Sync + 'static> FromCronContext for Service<T>
impl<T: Send + Sync + 'static> FromCronContext for Service<T>
Sourcefn from_cron_context(ctx: &CronContext) -> Result<Self>
fn from_cron_context(ctx: &CronContext) -> Result<Self>
Attempt to extract
Self from the given context. Read moreSourceimpl<T: Send + Sync + 'static> FromJobContext for Service<T>
impl<T: Send + Sync + 'static> FromJobContext for Service<T>
Sourcefn from_job_context(ctx: &JobContext) -> Result<Self>
fn from_job_context(ctx: &JobContext) -> Result<Self>
Extract
Self from the job context, returning an error if extraction
fails. Read moreSourceimpl<S, T> FromRequestParts<S> for Service<T>
impl<S, T> FromRequestParts<S> for Service<T>