pub fn path_param(name: &str) -> PathParamStrategyExpand description
Returns a strategy that reads the tenant slug from a named path parameter.
pub fn path_param(name: &str) -> PathParamStrategyReturns a strategy that reads the tenant slug from a named path parameter.