CookieConfig

Struct CookieConfig 

#[non_exhaustive]
pub struct CookieConfig { pub secret: String, pub secure: bool, pub http_only: bool, pub same_site: String, }
Cookie security attributes used by the session and flash middleware.

Deserializes from the cookie section of the application YAML config. All fields except secret have defaults, so a minimal config only needs to provide secret.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
secret: String

HMAC signing secret. Must be at least 64 characters long.

secure: bool

Set the Secure cookie attribute. Defaults to true.

Set to false during local HTTP development.

http_only: bool

Set the HttpOnly cookie attribute. Defaults to true.

same_site: String

SameSite cookie attribute value: "lax", "strict", or "none". Defaults to "lax".

Implementations

Source

impl CookieConfig

pub fn new(secret: impl Into<String>) -> Self

Create a new cookie configuration with the given signing secret.

Defaults: secure = true, http_only = true, same_site = "lax".