pub struct Query<T>(pub T);Expand description
Axum extractor that deserializes URL query parameters into T and then sanitizes it.
Returns a 400 Bad Request error if the query string cannot be deserialized into T.
T must implement both serde::de::DeserializeOwned and crate::sanitize::Sanitize.
Example
use modo::extractor::Query;
use modo::sanitize::Sanitize;
use serde::Deserialize;
#[derive(Deserialize)]
struct SearchParams { q: String, page: Option<u32> }
impl Sanitize for SearchParams {
fn sanitize(&mut self) { self.q = self.q.trim().to_lowercase(); }
}
async fn search(Query(params): Query<SearchParams>) {
// params.q is already trimmed and lowercased
}Tuple Fields
0: TTrait Implementations
Sourceimpl<S, T> FromRequestParts<S> for Query<T>
impl<S, T> FromRequestParts<S> for Query<T>